@@ -39,7 +39,7 @@
 
 /* RCS version string for later identification using rcs ident {{{*/
 #ifndef lint
-static volatile const char *RCSid = "@(#) $Id: cfg.c,v 1.3 2003/03/13 06:56:50 mbr Exp $";
+static volatile const char *RCSid = "@(#) $Id: cfg.c,v 1.4 2003/04/10 07:57:21 mbr Exp $";
 #endif
 /* }}} */
 
@@ -55,36 +55,10 @@ int parse_cfg_file(char *name) { /* {{{ */
 	int keyword_buffer_ptr = 0;
 	int argument_buffer_ptr = 0;
 	enum mode mode = MODE_INDENT;
-	config file_cfg = {
-		.daemon = UNDEFINED,
-		.apm = UNDEFINED,
-		.powermgt = UNDEFINED,
-		.nvram = NULL,
-		.polltime = UNDEFINED,
-		.tpbcmd = NULL,
-		.homecmd = NULL,
-		.searchcmd = NULL,
-		.mailcmd = NULL,
-		.callback = NULL,
-		.mixer = UNDEFINED,
-		.mixersteps = UNDEFINED,
-		.mixerdev = NULL,
-		.verbose = UNDEFINED,
-#ifdef HAVE_LIBXOSD
-		.osd = UNDEFINED,
-		.osdfont = NULL,
-		.osdcolor = NULL,
-		.osdtimeout = UNDEFINED,
-		.osdshadow = UNDEFINED,
-		.osdvertical = UNDEFINED,
-		.osdhorizontal = UNDEFINED,
-		.osdpos = UNDEFINED,
-#ifndef HAVE_LIBXOSD0
-		.osdalign = UNDEFINED
-#endif /* HAVE_LIBXOSD0 */
-#endif /* HAVE_LIBXOSD */
-	};
+	config file_cfg;
 
+	/* clear the config */
+	clear_cfg(&file_cfg);
 
 	/* open configuration file */
 	if((file_desc = fopen(name, "r")) == NULL) {
@@ -227,6 +201,38 @@ void init_cfg(void) { /* {{{ */
 	return;
 } /* }}} */
 
+void clear_cfg(config *cfg) { /* {{{ */
+		cfg->daemon = UNDEFINED;
+		cfg->apm = UNDEFINED;
+		cfg->powermgt = UNDEFINED;
+		cfg->nvram = NULL;
+		cfg->polltime = UNDEFINED;
+		cfg->tpbcmd = NULL;
+		cfg->homecmd = NULL;
+		cfg->searchcmd = NULL;
+		cfg->mailcmd = NULL;
+		cfg->callback = NULL;
+		cfg->mixer = UNDEFINED;
+		cfg->mixersteps = UNDEFINED;
+		cfg->mixerdev = NULL;
+		cfg->verbose = UNDEFINED;
+#ifdef HAVE_LIBXOSD
+		cfg->osd = UNDEFINED;
+		cfg->osdfont = NULL;
+		cfg->osdcolor = NULL;
+		cfg->osdtimeout = UNDEFINED;
+		cfg->osdshadow = UNDEFINED;
+		cfg->osdvertical = UNDEFINED;
+		cfg->osdhorizontal = UNDEFINED;
+		cfg->osdpos = UNDEFINED;
+#ifndef HAVE_LIBXOSD0
+		cfg->osdalign = UNDEFINED;
+#endif /* HAVE_LIBXOSD0 */
+#endif /* HAVE_LIBXOSD */
+
+	return;
+} /* }}} */
+
 void override_cfg(config *master) { /* {{{ */
 	/* override the defaults if the are set in master struct */
 	if(master->daemon != UNDEFINED) {
@@ -655,33 +661,10 @@ void set_value(char *key, char *arg, config *cfg) { /* {{{ */
 } /* }}} */
 
 void parse_option(int argc, char **argv) { /* {{{ */
-	config cmd_cfg = {
-		.daemon = UNDEFINED,
-		.apm = UNDEFINED,
-		.powermgt = UNDEFINED,
-		.nvram = NULL,
-		.polltime = UNDEFINED,
-		.tpbcmd = NULL,
-		.homecmd = NULL,
-		.searchcmd = NULL,
-		.mailcmd = NULL,
-		.callback = NULL,
-		.mixer = UNDEFINED,
-		.mixersteps = UNDEFINED,
-		.mixerdev = NULL,
-		.verbose = UNDEFINED,
-#ifdef HAVE_LIBXOSD
-		.osd = UNDEFINED,
-		.osdfont = NULL,
-		.osdcolor = NULL,
-		.osdtimeout = UNDEFINED,
-		.osdvertical = UNDEFINED,
-		.osdpos = UNDEFINED,
-#ifndef HAVE_LIBXOSD0
-		.osdalign = UNDEFINED
-#endif /* HAVE_LIBXOSD0 */
-#endif /* HAVE_LIBXOSD */
-	};
+	config cmd_cfg;
+
+	/* clear the config */
+	clear_cfg(&cmd_cfg);
 
 	while (1) {
 		int option_index = 0;
